#
# spec file for package libraqm
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 0
Name:           libraqm
Version:        0.10.2
Release:        1.3
Summary:        Complex Textlayout Library
License:        MIT
Group:          Development/Libraries/C and C++
URL:            https://github.com/HOST-Oman/libraqm
Source:         https://github.com/HOST-Oman/libraqm/releases/download/v%{version}/raqm-%{version}.tar.xz
BuildRequires:  freetype2-devel
BuildRequires:  fribidi-devel
BuildRequires:  gcc
BuildRequires:  gtk-doc
BuildRequires:  meson
BuildRequires:  pkgconfig(harfbuzz) >= 1.7.2

%description
Library that encapsulates the logic for complex
text layout and provides a convenient API.

%package -n %{name}%{sover}
Summary:        Complex Textlayout Library
Group:          System/Libraries
# The license and the generic %%doc files were moved to the library subpackage
Conflicts:      libraqm-doc < 0.7.2

%description -n %{name}%{sover}
Library that encapsulates the logic for complex
text layout and provides a convenient API.

%package doc
Summary:        Libraqm documentation
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
This package contains documentation files for raqm.

%package devel
Summary:        Complex Textlayout Library
Group:          Development/Libraries/C and C++
Requires:       %{name}%{sover} = %{version}

%description devel
Library that encapsulates the logic for complex
text layout and provides a convenient API.

%prep
%autosetup -n raqm-%{version} -p1

%build
%meson -Ddocs=true
%meson_build

%install
%meson_install

%check
# python 3.6 is too old for running tests
%if 0%{?suse_version} > 1500
export LC_ALL=C.utf8
%meson_test
%endif

%post -n %{name}%{sover} -p /sbin/ldconfig
%postun -n %{name}%{sover} -p /sbin/ldconfig

%files -n %{name}%{sover}
%license COPYING
%doc AUTHORS NEWS README.md
%{_libdir}/libraqm.so.*

%files devel
%{_includedir}/raqm.h
%{_includedir}/raqm-version.h
%{_libdir}/libraqm.so
%{_libdir}/pkgconfig/raqm.pc

%files doc
%{_datadir}/gtk-doc/html/raqm

%changelog
* Sat Sep 28 2024 Dirk Müller <dmueller@suse.com>
- update to 0.10.2:
  * Fix Unicode codepoint conversion from UTF-16.
* Thu Jan 18 2024 Dirk Müller <dmueller@suse.com>
- fix build on non-suse distributions
* Thu Apr 27 2023 Dirk Müller <dmueller@suse.com>
- update to 0.10.1:
  * Make combining marks always inherit the script of their base.
* Wed Jan 18 2023 Dirk Müller <dmueller@suse.com>
- update to v0.10.0:
  * Implement raqm_set_text_utf16
  * Fix font feature range
  * Fix resolved direction for all neutral text
  * Implement letter and word spacing support
* Mon Jan 31 2022 Paolo Stivanin <info@paolostivanin.com>
- update to 0.9.0:
  * raqm_t objects can now be reused by calling raqm_clear_contents()
    before re-use, to potentially reduce the number memory allocations.
  * don't hardcode python3 in tests.
  * new API:
  * raqm_set_freetype_load_flags_range()
  * raqm_clear_contents()
- Remove 0001-Pass_version_to_meson_library.patch as it was upstreamed
* Mon Dec 20 2021 Dirk Müller <dmueller@suse.com>
- update to 0.8.0:
  * Support using SheenBiDi instead of FriBiDi for Unicode BiDi support.
  * Fix running tests with Python <= 3.6.
  * New API:
  * raqm_get_par_resolved_direction
  * raqm_get_direction_at_index
* Thu Sep 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 0.7.2
  * Fix test failure with newer HarfBuzz versions.
  * Apply FT_Face transformation matrix when built against FreeType
    2.11 or later.
  * Add meson build system. Autotools build system will be dropped
    in next release.
  * Improve MSVC support (#134).
  * Build and documentation fixes.
- Drop upstream patch:
  * libraqm-fix-cursor_position-GB8a.patch
- Add upstream change:
  * 0001-Pass_version_to_meson_library.patch
* Tue Sep  7 2021 Jan Engelhardt <jengelh@inai.de>
- Drop libraqm-test.patch altogether, testsuite completes now
  on TW and SLE15.
- Remove unnecessary ldconfig calls.
* Tue Sep  7 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Add libraqm-fix-cursor_position-GB8a.patch: Fix test suite run,
  patch cherry-picked from upstream commit 9badec46.
* Sun Aug 22 2021 Fusion Future <qydwhotmail@gmail.com>
- Make libraqm-test.patch apply to all suse versions to fix build.
- Use "pkgconfig(harfbuzz) >= 1.7.2" as build requirement.
* Fri Apr  2 2021 Wang Jun <jgwang@suse.com>
- Update to version 0.7.1
  * Require HarfBuzz >= 2.0.0
  * Build and documentation fixes.
* Mon May 11 2020 Joop Boonen <joop.boonen@opensuse.org>
- Build version 0.7.0
  * New functions:
    raqm_version()
    raqm_version_string()
    raqm_version_atleast()
  * New macros:
    RAQM_VERSION_MAJOR
    RAQM_VERSION_MICRO
    RAQM_VERSION_MINOR
    RAQM_VERSION_STRING
    RAQM_VERSION_ATLEAST()
- Since version 0.6.0
  * Fix TTB direction regression from the previous release (#81)
  * Add raqm_set_invisible_glyph() (#92)
  * Correctly detect script of Common and Inherite characters at start of text (#95)
  * Undef HAVE_CONFIG_H workaround, for older versions of Fribidi (#101)
  * Drop test suite dependency on GLib
  * Port test runner to Python instead of shell script
- Renamed patch libraqm-GB8a.patch to libraqm-test.patch
* Tue Feb 12 2019 Jan Engelhardt <jengelh@inai.de>
- Rename %%soname to %%sover to better reflect its use.
- Rename libraqm-docs to libraqm-doc to better match the
  rest of openSUSE packages.
- Fix RPM groups.
- Avoid double-shipping doc files.
* Thu Dec 27 2018 Joop Boonen <joop.boonen@opensuse.org>
- Build the opensuse version of this package
* Sun Nov 18 2018 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl>
- Use C.UTF-8 locale
  See https://fedoraproject.org/wiki/Changes/Remove_glibc-langpacks-all_from_buildroot
* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org>
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild
* Wed Mar 14 2018 Elliott Sales de Andrade <quantum.analyst@gmail.com>
- Update to latest version
* Wed Feb  7 2018 Fedora Release Engineering <releng@fedoraproject.org>
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild
* Thu Aug  3 2017 Fedora Release Engineering <releng@fedoraproject.org>
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild
* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org>
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild
* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org>
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild
* Sun May  1 2016 Mosaab Alzoubi <moceap@hotmail.com>
- Updated to 0.1.1
* Mon Apr 25 2016 Mosaab Alzoubi <moceap@hotmail.com>
- Use lib prefix in %%%%name
- Depends on same version -devel
* Sun Apr 24 2016 Mosaab Alzoubi <moceap@hotmail.com>
- General revision
* Sat Apr 23 2016 Mosaab Alzoubi <moceap@hotmail.com>
- Initial build
